<?xml version="1.0" encoding="UTF-8"?>
<xsl:stylesheet xmlns:xsl="http://www.w3.org/1999/XSL/Transform" version="1.0">
  <xsl:output method="html" />

  <!--
      Colloquy MediaWiki Pretty Print 
      Transform a Colloquy XML chat log into Mediawiki wiki format

      The output includes inline anchors so that specific times can easily be
      linked to.

      For a sample of the output, see

        https://wiki.mozilla.org/Project/2010_Goals/IRC/2010goals/2008-10-23

      To apply the script, open a terminal and run the following command,
      ensuring that you input the right paths for the referenced files.

        xsltproc colloquy-mw-prettyprint.xsl path/to/transcript.xml > output.txt

      The results will be stored in output.txt

      You will need to add the following class info to your MediaWiki CSS

      .irc-log tr > td:first-child {
          color: #555;
          font-weight: bold;
          text-align: right;
          vertical-align: top;
      }

      .irc-log tr td {
          border-bottom: 1px solid #DDD;
      }

      .irc-log td + td + td {
          color: #555;
          font-size: 80%;
          vertical-align: top;
      }

      Note: The script is intended for 24 hour or less of logs.
  -->

  <xsl:template match="/">
    <xsl:apply-templates />
  </xsl:template>

  <xsl:template match="/log">
    <xsl:text>'''Log from channel </xsl:text>
    <xsl:value-of select="substring-before(@source, '%23')" />
    <xsl:text>#</xsl:text>
    <xsl:value-of select="substring-after(@source, '%23')" />
    <xsl:text> starting </xsl:text>
    <xsl:value-of select="@began" />
    <xsl:text>'''&#xA;&#xA;</xsl:text>
    <xsl:text>Link to a time in the conversation by visiting a URL like {{fullurl:{{FULLPAGENAME}}}}#12:00&#xA;</xsl:text>
    <xsl:text>----&#xA;</xsl:text>
    <xsl:text>{| class="irc-log"</xsl:text>
    <xsl:apply-templates />
    <xsl:text>|}</xsl:text>
  </xsl:template>

  <xsl:template match="/log/event | /log/envelope">
    <xsl:choose>
      <xsl:when test="local-name() = 'event'">
        <xsl:call-template name="start-row" />
        <xsl:text>| <!-- empty cell --> || style="color: #555;" | » </xsl:text>
        <xsl:value-of select="normalize-space(message)" />
        <xsl:call-template name="timestamp">
          <xsl:with-param name="datetime" select="@occurred" />
        </xsl:call-template>
      </xsl:when>

      <xsl:when test="local-name() = 'envelope'">
        <xsl:variable name="sender" select="sender" />

        <xsl:for-each select="message">
          <xsl:call-template name="start-row" />
          <xsl:text>| </xsl:text>
          <xsl:value-of select="$sender" />
          <xsl:text> || </xsl:text><xsl:value-of select="normalize-space(.)" />
          <xsl:call-template name="timestamp">
            <xsl:with-param name="datetime" select="@received" />
          </xsl:call-template>
        </xsl:for-each>
      </xsl:when>

      <xsl:otherwise>
        <xsl:text>ERROR: can't handle "</xsl:text><xsl:value-of select="local-name()" /><xsl:text>"</xsl:text>
      </xsl:otherwise>
    </xsl:choose>
  </xsl:template>

  <xsl:template name="start-row">
    <xsl:text>&#xA;|-&#xA;</xsl:text>
  </xsl:template>

  <xsl:template name="timestamp">
    <xsl:param name="datetime" /> <!-- YYYY-MM-DD HH:MM +/-HHMM -->
    <xsl:variable name='time' select='substring($datetime, 12, 5)' />

    <xsl:text> || id="</xsl:text><xsl:value-of select="$time" /><xsl:text>" | </xsl:text>
    <xsl:value-of select="$time" />
  </xsl:template>
</xsl:stylesheet>
